@@ -294,7 +294,7 @@ QByteArray KIMAP::encodeImapFolderName(const QByteArray &inSrc)
 QTextCodec *KIMAP::codecForName(const QString &str)
 {
     if (str.isEmpty()) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     return QTextCodec::codecForName(str.toLower().
                                     replace(QStringLiteral("windows"), QStringLiteral("cp")).toLatin1());
@@ -330,7 +330,7 @@ const QString KIMAP::decodeRFC2047String(const QString &str,
     // FIXME get rid of the conversion?
     QByteArray aStr = str.toLatin1();   // QString.length() means Unicode chars
     QByteArray result;
-    char *pos, *beg, *end, *mid = Q_NULLPTR;
+    char *pos, *beg, *end, *mid = nullptr;
     QByteArray cstr;
     char encoding = 0, ch;
     bool valid;
@@ -571,7 +571,6 @@ const QString KIMAP::encodeRFC2231String(const QString &str)
     signed char *l = latin;
     char hexcode;
     int i;
-    bool quote;
     while (*l) {
         if (*l < 0) {
             break;
@@ -585,7 +584,7 @@ const QString KIMAP::encodeRFC2231String(const QString &str)
     QByteArray result;
     l = latin;
     while (*l) {
-        quote = *l < 0;
+        bool quote = *l < 0;
         for (i = 0; i < 16; ++i) {
             if (*l == especials[i]) {
                 quote = true;
